@@ -1,57 +1,63 @@
 #' Hierarchical piecewise linear model / piecewise regression
-#' 
+#'
 #' The \code{hplm} function computes a hierarchical piecewise regression model.
-#' 
+#'
 #' @inheritParams .inheritParams
 #' @param method Method used to fit your model. Pass \code{"REML"} to maximize
-#' the restricted log-likelihood or \code{"ML"} for maximized log-likelihood.
-#' Default is \code{"ML"}.
-#' @param control A list of settings for the estimation algorithm, replacing
-#' the default values passed to the function \code{lmeControl} of the
-#' \code{nlme} package.
+#'   the restricted log-likelihood or \code{"ML"} for maximized log-likelihood.
+#'   Default is \code{"ML"}.
+#' @param control A list of settings for the estimation algorithm, replacing the
+#'   default values passed to the function \code{lmeControl} of the \code{nlme}
+#'   package.
 #' @param random.slopes If \code{random.slopes = TRUE} random slope effects of
-#' the level, trend, and treatment parameter are estimated.
-#' @param lr.test If set TRUE likelihood ratio tests are calculated comparing model with vs. without random slope parameters.
+#'   the level, trend, and treatment parameter are estimated.
+#' @param lr.test If set TRUE likelihood ratio tests are calculated comparing
+#'   model with vs. without random slope parameters.
 #' @param ICC If \code{ICC = TRUE} an intraclass-correlation is estimated.
-#' @param fixed Defaults to the fixed part of the standard piecewise regression model. The
-#' parameter phase followed by the phase name (e.g., phaseB) indicates the level effect of the corresponding phase. The parameter 'inter' followed by the phase name (e.g., interB) adresses the slope effect based on the method
-#' provide in the model argument (e.g., "B&L-B"). The formula can be changed
-#' for example to include further L1 or L2 variables into the regression model.
+#' @param fixed Defaults to the fixed part of the standard piecewise regression
+#'   model. The parameter phase followed by the phase name (e.g., phaseB)
+#'   indicates the level effect of the corresponding phase. The parameter
+#'   'inter' followed by the phase name (e.g., interB) adresses the slope effect
+#'   based on the method provide in the model argument (e.g., "B&L-B"). The
+#'   formula can be changed for example to include further L1 or L2 variables
+#'   into the regression model.
 #' @param random The random part of the model.
-#' @param update.fixed An easier way to change the fixed model part (e.g., . ~ . + newvariable).
+#' @param update.fixed An easier way to change the fixed model part (e.g., . ~ .
+#'   + newvariable).
 #' @param data.l2 A dataframe providing additional variables at Level 2. The
-#' scdf File has to have names for all cases and the Level 2 dataframe has to
-#' have a column named 'cases' with the names of the cases the Level 2
-#' variables belong to.
+#'   scdf File has to have names for all cases and the Level 2 dataframe has to
+#'   have a column named 'cases' with the names of the cases the Level 2
+#'   variables belong to.
 #' @param ... Further arguments passed to the lme function.
-#' @return 
-#' \item{model}{List containing infromation about the applied model} 
-#' \item{N}{Number of single-cases.}
-#' \item{formla}{A list containing the fixed and the random formulas of the hplm model.}
-#' \item{hplm}{Object of class lme contaning the multilevel model} 
-#' \item{model.0}{Object of class lme containing the Zero Model.} 
-#' \item{ICC}{List containing intraclass correlation and test parameters.}
-#' \item{model.without}{Object of class gls containing the fixed effect model.}
+#' @return \item{model}{List containing infromation about the applied model}
+#' \item{N}{Number of single-cases.} \item{formla}{A list containing the fixed
+#' and the random formulas of the hplm model.} \item{hplm}{Object of class lme
+#' contaning the multilevel model} \item{model.0}{Object of class lme containing
+#' the Zero Model.} \item{ICC}{List containing intraclass correlation and test
+#' parameters.} \item{model.without}{Object of class gls containing the fixed
+#' effect model.}
 #' @author Juergen Wilbert
 #' @family regression functions
 #' @examples
-#' 
+#'
 #' ## Compute hplm model on a MBD over fifty cases (restricted log-likelihood)
 #' hplm(exampleAB_50, method = "REML", random.slopes = FALSE)
-#' 
+#'
 #' ## Analyzing with additional L2 variables
-#' hplm(Leidig2018, data.l2 = Leidig2018_l2, 
-#'      update.fixed = .~. + gender + migration + ITRF_TOTAL*phaseB, 
-#'      slope = FALSE, random.slopes = FALSE, lr.test = FALSE)
-#'      
+#' Leidig2018 %>% 
+#'   add_l2(Leidig2018_l2) %>% 
+#'   hplm(update.fixed = .~. + gender + migration + ITRF_TOTAL*phaseB,
+#'        slope = FALSE, random.slopes = FALSE, lr.test = FALSE
+#'   )    
+#'
 #' @export
 
 hplm <- function(data, dvar, pvar, mvar, 
-                 model = "W", 
-                 contrast = "first",
+                 model = c("W", "H-M", "B&L-B", "JW"),
+                 contrast = c("first", "preceding"),
                  contrast_level = NA,
                  contrast_slope = NA,
-                 method = "ML", 
+                 method = c("ML", "REML"), 
                  control = list(opt = "optim"), 
                  random.slopes = FALSE, 
                  lr.test = FALSE, 
@@ -65,6 +71,15 @@ hplm <- function(data, dvar, pvar, mvar,
                  data.l2 = NULL, 
                  ...) {
 
+  check_args(
+    by_call(model, "hplm"),
+    by_call(method, "hplm"),
+    by_call(contrast, "hplm")
+  )
+  model <- model[1]
+  method <- method[1]
+  contrast <- contrast[1]
+  
   if (is.na(contrast_level)) contrast_level <- contrast
   if (is.na(contrast_slope)) contrast_slope <- contrast
   
@@ -73,12 +88,7 @@ hplm <- function(data, dvar, pvar, mvar,
     contrast_slope <- "preceding"
     model <- "B&L-B"
   }
-  
 
-  start_check() %>%
-    check_in(model, c("H-M", "B&L-B", "W")) %>%
-    end_check()
-  
   # set attributes to arguments else set to defaults of scdf
   if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv)
   if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) 
