@@ -3,16 +3,17 @@
   
   # check class scdf validity
   if (.opt$rigorous_class_check) {
-    results <- .check_scdf(data)
-    if (!isTRUE(results)) {
-      if(length(results$warnings) > 0) {
-        warning(results$warnings)
-      }
-      if(length(results$errors) > 0) {
-        stop(results$errors)
-      }
-    } 
+    check_scdf(data)
   }
+  #   if (!isTRUE(results)) {
+  #     if(length(results$warnings) > 0) {
+  #       warning(results$warnings)
+  #     }
+  #     if(length(results$errors) > 0) {
+  #       stop(results$errors)
+  #     }
+  #   } 
+  # }
 
   pvar <- scdf_attr(data, .opt$phase)
   mvar <- scdf_attr(data, .opt$mt)
